Documentation
¶
Index ¶
- Constants
- type Credential
- type Flow
- func (f *Flow) GetInputDefinition(b *data.BuildFile, env *merge.Envar) (*data.Input, error)
- func (f *Flow) IsValid() error
- func (f *Flow) JsonBytes() ([]byte, error)
- func (f *Flow) Map() (map[string]interface{}, error)
- func (f *Flow) RequiresFile() bool
- func (f *Flow) RequiresGitSource() bool
- func (f *Flow) RequiresSecrets() bool
- func (f *Flow) Step(name string) *Step
- func (f *Flow) StepByFx(fxName string) *Step
- type Git
- type Item
- type Manager
- func (m *Manager) AddLabels(labels []string)
- func (m *Manager) JsonString() (string, error)
- func (m *Manager) Merge(interactive bool) error
- func (m *Manager) Run(runnerName, creds string, interactive bool) error
- func (m *Manager) SaveJSON() error
- func (m *Manager) SaveOnixJSON() error
- func (m *Manager) SaveYAML() error
- func (m *Manager) YamlString() (string, error)
- type Step
Constants ¶
const ( GitUriDesc = "the URI of the GIT repository" GitBranchDesc = "the branch to be used to clone the project from the GIT repository" GitUserDesc = "the user name to be used to authenticate with the GIT repository" GitPasswordDesc = "the password or token to be used to authenticate with the GIT repository" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Credential ¶
Credential a set of authentication credentials for a package registry
type Flow ¶
type Flow struct {
Name string `yaml:"name"`
Description string `yaml:"description"`
// a list of labels to document key aspects of the flow execution
// for example using a target namespace if running in Kubernetes
Labels map[string]string `yaml:"labels" json:"labels"`
Git *Git `yaml:"git,omitempty" json:"git,omitempty"`
Steps []*Step `yaml:"steps" json:"steps"`
Input *data.Input `yaml:"input,omitempty" json:"input,omitempty"`
UseRuntimes *bool `yaml:"use_runtimes,omitempty" json:"use_runtimes,omitempty"`
// contains filtered or unexported fields
}
func (*Flow) GetInputDefinition ¶
GetInputDefinition retrieve all input data required by the flow without values interactive mode is off - gets definition only
func (*Flow) RequiresFile ¶
func (*Flow) RequiresGitSource ¶
func (*Flow) RequiresSecrets ¶
type Item ¶
type Item struct {
Key string `json:"key"`
Name string `json:"name"`
Description string `json:"description"`
Status int `json:"status"`
Type string `json:"type"`
Tag []interface{} `json:"tag"`
Meta map[string]interface{} `json:"meta"`
Txt string `json:"txt"`
Attribute map[string]interface{} `json:"attribute"`
Partition string `json:"partition"`
Version int64 `json:"version"`
Created string `json:"created"`
Updated string `json:"updated"`
EncKeyIx int64 `json:"encKeyIx"`
ChangedBy string `json:"changedBy"`
}
type Manager ¶
type Manager struct {
Flow *Flow
// contains filtered or unexported fields
}
Manager manages an Artisan flow the pipeline generator requires at least the flow definition if a build file is passed then step variables can be inferred from it
func NewWithEnv ¶
func (*Manager) JsonString ¶
func (*Manager) SaveOnixJSON ¶
func (*Manager) YamlString ¶
type Step ¶
type Step struct {
Name string `yaml:"name" json:"name"`
Description string `yaml:"description,omitempty" json:"description,omitempty"`
Function string `yaml:"function,omitempty" json:"function,omitempty"`
Package string `yaml:"package,omitempty" json:"package,omitempty"`
PackageSource string `yaml:"source,omitempty" json:"source,omitempty"`
Input *data.Input `yaml:"input,omitempty" json:"input,omitempty"`
Privileged bool `yaml:"privileged" json:"privileged"`
}
Click to show internal directories.
Click to hide internal directories.